using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;


namespace P6_2
{
    /// <summary>
    /// Это игровой компонент, реализующий интерфейс IUpdateable.
    /// </summary>
    public class spriteComp : Microsoft.Xna.Framework.DrawableGameComponent
    {
        //Изображение
        private Texture2D sprTexture;
        //Прямоугольник, ограничивающий спрайт
        private Rectangle sprRectangle;
        //Координата спрайта
        private Vector2 sprPosition;
        //Границы экрана
        private Rectangle scrBounds;
        //Направление движения спрайта
        private Vector2 sprMove = new Vector2(0, 0);
        public spriteComp(Game game, ref Texture2D newTexture,
            Rectangle newRectangle, Vector2 newPosition
)
            : base(game)
        {
            sprTexture = newTexture;
            sprRectangle = newRectangle;
            sprPosition = newPosition;
            //Работаем в портретном режиме, высота - 480, ширина - 800
            scrBounds = new Rectangle(0, 0,
                game.Window.ClientBounds.Height,
                game.Window.ClientBounds.Width
                );
        }

        /// <summary>
        /// Позволяет игровому компоненту выполнить необходимую инициализацию перед\r\запуском.  Здесь можно запросить нужные службы и загрузить контент.
        /// 
        /// </summary>
        public override void Initialize()
        {
            // ЗАДАЧА: добавьте здесь код инициализации

            base.Initialize();
        }

        /// <summary>
        /// Позволяет игровому компоненту обновиться.
        /// </summary>
        /// <param name="gameTime">Предоставляет моментальный снимок значений времени.</param>
        public override void Update(GameTime gameTime)
        {
            //Изменение координат в соответствии с данными, имеющимися в sprMove
            sprPosition.Y = sprPosition.Y + sprMove.Y;
            sprPosition.X = sprPosition.X + sprMove.X;
            //Если вышли за пределы экрана - исправляем 
            //и сбрасываем скорость в направлении, в котором
            //пересекли границу
            if (sprPosition.X < scrBounds.Left)
            {
                sprPosition.X = scrBounds.Left;
                sprMove.X = 0;
            }
            if (sprPosition.X > scrBounds.Width - sprRectangle.Width)
            {
                sprPosition.X = scrBounds.Width - sprRectangle.Width;
                sprMove.X = 0;
            }
            if (sprPosition.Y < scrBounds.Top)
            {
                sprPosition.Y = scrBounds.Top;
                sprMove.Y = 0;
            }
            if (sprPosition.Y > scrBounds.Height - sprRectangle.Height)
            {
                sprPosition.Y = scrBounds.Height - sprRectangle.Height;
                sprMove.Y = 0;
            }

            base.Update(gameTime);
        }
        public override void Draw(GameTime gameTime)
        {
            SpriteBatch sprBatch =
                (SpriteBatch)Game.Services.GetService(typeof(SpriteBatch));

            sprBatch.Draw(sprTexture, sprPosition, sprRectangle, Color.White);

            base.Draw(gameTime);
        }
        //Метод для установки направления движения спрайта
        public void Move(Vector2 move)
        {   
            //Изменяем вектор, задающий направление и скорость движения спрайта
            sprMove += move;
            //Ограничиваем скорость 5-ю пикселями
            if (sprMove.X > 5) { sprMove.X = 5; }
            if (sprMove.X < -5) { sprMove.X = -5; }
            if (sprMove.Y > 5) { sprMove.Y = 5; }
            if (sprMove.Y < -5) { sprMove.Y = -5; }
        }
    }
}
